//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraArgs](index.md)/[HoraArgs](-hora-args.md)

# HoraArgs

[common]\
constructor(tiles: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;, furo: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Furo](../../mahjongutils.models/-furo/index.md)&gt; = DEFAULT_FURO, agari: [Tile](../../mahjongutils.models/-tile/index.md), tsumo: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html), dora: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) = DEFAULT_DORA, selfWind: [Wind](../../mahjongutils.models/-wind/index.md)? = DEFAULT_SELF_WIND, roundWind: [Wind](../../mahjongutils.models/-wind/index.md)? = DEFAULT_ROUND_WIND, extraYaku: [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;@Serializable(with = [DefaultYakuSerializer::class](../../mahjongutils.yaku/-default-yaku-serializer/index.md))[Yaku](../../mahjongutils.yaku/-yaku/index.md)&gt; = DEFAULT_EXTRA_YAKU, options: [HoraOptions](../-hora-options/index.md) = DEFAULT_OPTIONS)

constructor(shantenResult: [CommonShantenResult](../../mahjongutils.shanten/-common-shanten-result/index.md)&lt;*&gt;, agari: [Tile](../../mahjongutils.models/-tile/index.md), tsumo: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html), dora: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) = DEFAULT_DORA, selfWind: [Wind](../../mahjongutils.models/-wind/index.md)? = DEFAULT_SELF_WIND, roundWind: [Wind](../../mahjongutils.models/-wind/index.md)? = DEFAULT_ROUND_WIND, extraYaku: [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;@Serializable(with = [DefaultYakuSerializer::class](../../mahjongutils.yaku/-default-yaku-serializer/index.md))[Yaku](../../mahjongutils.yaku/-yaku/index.md)&gt; = DEFAULT_EXTRA_YAKU, options: [HoraOptions](../-hora-options/index.md) = DEFAULT_OPTIONS)
